@@ -294,7 +294,7 @@ tc_aP<-output_tc(filepath = file_nm, percent=TRUE)
 ###All peptides drawn 
 robot_plot_All(thP = tc_aP, th=tc_a)
 ###USe more stingent parameters to have less peptides drawn. CI_factor is a factor that modifies (multiplicate) Critial interval. 
-robot_plot_All(thP = tc_aP, th=tc_a, pv_cutoff=0.005, CI_factor = 5)
+robot_plot_All(thP = tc_aP, th=tc_a, pv_cutoff=0.005, replicates = 3)
 
 
 
@@ -312,12 +312,11 @@ robot_indexes_df(thP = tc_aP, th=tc_a, states=rev(names_states)[1:2],
 
 #list of indexes 
 inds<-robot_indexes(thP = tc_aP, th=tc_a, states=rev(names_states)[1:2], 
-                    pvalue = 0.005, CI_factor=1.5) ###return indexes of peptide
+                    pvalue = 0.001, CI_factor=1) ###return indexes of peptide
 
-inds2=inds[c(1,4, 7,8, 9, 11,13,14, 15,16, 20,21, 24)] ### pick which peptides you want to keep 
 
 # Make a final robot plot. Above the plot there is bar that showing lack of coverage in the sets (grey), no coverage on plot (blue), coverage on plot (orange). 
-robot_2states_indexes(thP = tc_aP, th=tc_a, states=rev(names_states)[1:2],indexes = inds2, pvalue=0.001, CI_factor = 2, ylim=c(-120, 120), xlim=c(50, 230))
+robot_2states_indexes(thP = tc_aP, th=tc_a, states=rev(names_states)[1:2],indexes = inds,  pvalue = 0.001, CI_factor=1,  ylim=c(-120, 120), xlim=c(50, 230))
 
 
 ## ----fig_woods_CI, fig.height = 5, fig.width = 5------------------------------
@@ -331,7 +330,7 @@ tc_aP<-output_tc(filepath = file_nm, percent=TRUE)
 ###All peptides drawn 
 woods_CI_plot(thP = tc_aP, th=tc_a)
 ###USe more stingent parameters to have less peptides drawn. CI_factor is a factor that modifies (multiplicate) Critial interval. 
-woods_CI_plot(thP = tc_aP, th=tc_a, pv_cutoff=0.005, CI_factor = 5)
+woods_CI_plot(thP = tc_aP, th=tc_a, pv_cutoff=0.05, CI_factor = 2)
 
 
 
